==> Tagz-1.0.0.zip: Tagz/lang/en.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Keywords',
 'L_TITLE'=>'Edit site keywords',
 'L_DESCRIPTION'=>'Manage site tags. Delete or rename the set of keywords.',
#admin
 'L_CANCEL'=>'Cancel all',
 'L_DEVIENT'=>'becomes',
 'L_POUR'=>'for',
 'L_SEARCH'=>'Search in articles with this keyword',
 'L_RESTORE'=>'Restore',
 'L_DEL'=>'Wipe off',
 'L_RESTORE_ALL'=>'Restore all fields left empty',
 'L_DEL_ALL'=>'Clear all fields',
 'L_ART_NUM'=>'For the item (s) with number (s)',
 'L_HELP_TAG_FIELD'=>'If the field is empty, this deletes the keyword after saving.'.PHP_EOL.'La combinaison de touche Ctrl + z permet d’annuler',
 'L_TAGS_REFRESH'=>'Refresh',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Tags.xml file refreshed by the keywords of the articles',
 'L_TAG_PLACEHOLDER'=>'Deleted if left empty',
 'L_DEDUPLICATED'=>'deduplicated',
 'L_IN_REALITY'=>'In reality',
 'L_IS_UNIK'=>'Unique (is solo)',
 'L_DOUBLES'=>'double',
 'L_TRIPLES'=>'Triplets',
 'L_QUADRUPLES'=>'Quadruplets',
 'L_QUINTUPLES'=>'Quintuplets',
 'L_SEXTUPLES'=>'Sextuplets',
 'L_SEPTUPLES'=>'Septuplets',
#config
 'L_ACCES'=>'Type (s) of account (s) * authorized to access the plugin',
 'L_HELP_ACCES'=>'Which profiles * are allowed to use the plugin. List separated by commas (Default PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'User (s) prohibited from accessing the plugin (Hidden menu)',
 'L_HELP_DENY'=>'Which are the identifiers of the users to whom it is forbidden to use the plugin. Comma-separated list (For example 001,002,007).'
);
?>

==> Tagz-1.0.4.zip: Tagz/lang/en.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Keywords',
 'L_TITLE'=>'Edit site keywords',
 'L_DESCRIPTION'=>'Manage site tags. Delete or rename the set of keywords.',
 'L_FILTER_TAGS'=>'Filter keywords',
 'L_FILTER_TAGS_PH'=>'Word filter',
 'L_CANCEL'=>'Cancel all',
 'L_DEVIENT'=>'becomes',
 'L_POUR'=>'for',
 'L_SEARCH'=>'Search in articles with this keyword',
 'L_RESTORE'=>'Restore',
 'L_DEL'=>'Wipe off',
 'L_RESTORE_ALL'=>'Restore all fields left empty',
 'L_DEL_ALL'=>'Clear all fields',
 'L_ART_NUM'=>'For the item (s) with number (s)',
 'L_HELP_TAG_FIELD'=>'If the field is empty, this deletes the keyword after saving.',
 'L_HELP_TAG_CTRLZ'=>'The combination of Ctrl-z keys allows you to cancel',
 'L_TAGS_REFRESH'=>'Refresh',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Tags.xml file refreshed by the keywords of the articles',
 'L_TAG_PLACEHOLDER'=>'Deleted if left empty',
 'L_DEDUPLICATED'=>'deduplicated',
 'L_IN_REALITY'=>'In reality',
 'L_IS_UNIK'=>'Unique (is solo)',
 'L_DOUBLES'=>'double',
 'L_TRIPLES'=>'Triplets',
 'L_QUADRUPLES'=>'Quadruplets',
 'L_QUINTUPLES'=>'Quintuplets',
 'L_SEXTUPLES'=>'Sextuplets',
 'L_SEPTUPLES'=>'Septuplets',
 'L_OCTUPLES'=>'Octuples',
 'L_NONUPLES'=>'Nonuples',
 'L_DECUPLES'=>'Tenfold',
#config
 'L_ACCES'=>'Type (s) of account (s) * authorized to access the plugin',
 'L_HELP_ACCES'=>'Which profiles * are allowed to use the plugin. List separated by commas (Default PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'User (s) prohibited from accessing the plugin (Hidden menu)',
 'L_HELP_DENY'=>'Which are the identifiers of the users to whom it is forbidden to use the plugin. Comma-separated list (For example 001,002,007).',
);
?>
